==> igniteui-webcomponents-core-3.2.2.tgz: package/esm5/lib/WebMoveTabActionDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebPaneDragActionDescriptionMetadata } from "./WebPaneDragActionDescriptionMetadata";
import { WebMoveTabActionDescription } from "./WebMoveTabActionDescription";
/**
 * @hidden
 */
var WebMoveTabActionDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(WebMoveTabActionDescriptionMetadata, _super);
    function WebMoveTabActionDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebMoveTabActionDescriptionMetadata.b = function (a) {
        if (WebMoveTabActionDescriptionMetadata.a == null) {
            WebMoveTabActionDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebMoveTabActionDescriptionMetadata.c(WebMoveTabActionDescriptionMetadata.a);
        }
        if (a.g(WebMoveTabActionDescriptionMetadata.a)) {
            return;
        }
        a.s(WebMoveTabActionDescriptionMetadata.a);
    };
    WebMoveTabActionDescriptionMetadata.c = function (a) {
        WebPaneDragActionDescriptionMetadata.c(a);
        a.item("__qualifiedNameTS", "String:MoveTabAction");
        a.item("ActionType", "(wc:Type)ExportedType:string:PaneDragActionType");
        a.item("ActionType@names", "FloatPane;MoveFloatingPane;DockPane;MoveTab");
        a.item("OldIndex", "Number:double");
        a.item("NewIndex", "Number:double");
    };
    WebMoveTabActionDescriptionMetadata.d = function (a) {
        WebMoveTabActionDescriptionMetadata.b(a);
        a.u("WebMoveTabAction", function () { return new WebMoveTabActionDescription(); });
        a.t("WebMoveTabAction", WebMoveTabActionDescriptionMetadata.a);
    };
    WebMoveTabActionDescriptionMetadata.$t = markType(WebMoveTabActionDescriptionMetadata, 'WebMoveTabActionDescriptionMetadata');
    WebMoveTabActionDescriptionMetadata.a = null;
    return WebMoveTabActionDescriptionMetadata;
}(Base));
export { WebMoveTabActionDescriptionMetadata };

==> igniteui-webcomponents-core-4.0.2.tgz: package/esm5/lib/WebMoveTabActionDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebPaneDragActionDescriptionMetadata } from "./WebPaneDragActionDescriptionMetadata";
import { WebMoveTabActionDescription } from "./WebMoveTabActionDescription";
/**
 * @hidden
 */
var WebMoveTabActionDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(WebMoveTabActionDescriptionMetadata, _super);
    function WebMoveTabActionDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebMoveTabActionDescriptionMetadata.b = function (a) {
        if (WebMoveTabActionDescriptionMetadata.a == null) {
            WebMoveTabActionDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebMoveTabActionDescriptionMetadata.c(WebMoveTabActionDescriptionMetadata.a);
        }
        if (a.j(WebMoveTabActionDescriptionMetadata.a)) {
            return;
        }
        a.y(WebMoveTabActionDescriptionMetadata.a);
    };
    WebMoveTabActionDescriptionMetadata.c = function (a) {
        WebPaneDragActionDescriptionMetadata.c(a);
        a.item("__qualifiedNameTS", "String:MoveTabAction");
        a.item("ActionType", "(wc:Type)ExportedType:string:PaneDragActionType");
        a.item("ActionType@names", "FloatPane;MoveFloatingPane;DockPane;MoveTab");
        a.item("OldIndex", "Number:double");
        a.item("NewIndex", "Number:double");
    };
    WebMoveTabActionDescriptionMetadata.d = function (a) {
        WebMoveTabActionDescriptionMetadata.b(a);
        a.aa("WebMoveTabAction", function () { return new WebMoveTabActionDescription(); });
        a.z("WebMoveTabAction", WebMoveTabActionDescriptionMetadata.a);
    };
    WebMoveTabActionDescriptionMetadata.$t = markType(WebMoveTabActionDescriptionMetadata, 'WebMoveTabActionDescriptionMetadata');
    WebMoveTabActionDescriptionMetadata.a = null;
    return WebMoveTabActionDescriptionMetadata;
}(Base));
export { WebMoveTabActionDescriptionMetadata };
